#!/bin/sh

# 定义变量
P11_MODULE_NAME="mTokenGM3000"
INSTALL_PATH="/opt/apps/com.longser.gm3000user/files"
LIB_PATH="${INSTALL_PATH}/lib"
CERT_PATH="${INSTALL_PATH}/cert"
CERT_LIST="CFCA_ACS_CA.crt CFCA_ACS_OCA31.crt mToken_Plugin_CA.crt"
PKCS11_LIB="${LIB_PATH}/libgm3000_pkcs11.so"
USERNAME=$(whoami)

isOK ()
{
    [ $1 -eq 0 ] && echo "$2[\033[32m成功\033[0m]" || echo "$2[\033[31m失败\033[0m]"
}

# 往浏览器里注册pkcs11模块和导入证书链
echo "开始注册PKCS#11模块和导入证书链到浏览器中..."
if [ "$( which certutil )" = "" ];then
    echo "系统未安装 libnss3-tools 工具，无法注册PKCS#11模块和导入证书链。"
    echo "请手动将${LIB_PATH}下的${PKCS11_LIB}和${CERT_PATH}下的证书文件导入到浏览器中。"
else
    for certDB in $(find /home/${USERNAME} -name "cert9.db"); do
        certDBPath=$(dirname ${certDB})
        userPath=${certDBPath#/home/}
        username=${userPath%%/*}
        echo "为用户 ${username} 注册PKCS#11模块和导入证书链到${certDBPath}下的cert9.db中。"
        echo -n "    "
        mod_info=`modutil -dbdir sql:${certDBPath} -list|grep ${P11_MODULE_NAME}`
        if [ -n "$mod_info" ]; then
            echo "已经注册PKCS#11模块 ${P11_MODULE_NAME}，无需重复注册。" 
        else
            modutil -dbdir sql:${certDBPath} -add ${P11_MODULE_NAME} -libfile ${PKCS11_LIB} -force
            isOK $? "    注册PKCS#11模块 ${P11_MODULE_NAME} "
        fi
        for certFile in $(find ${CERT_PATH} -maxdepth 1 -name "*.crt"); do
            certFileName=${certFile##*/}
            certName=${certFileName%%.crt}
            certName=`echo $certName | sed "s/_/ /g"`
            echo -n "    "
            cert_info=`certutil -d sql:${certDBPath} -L|grep "${certName}"`
            if [ -n "$cert_info" ]; then
                echo "证书${certName} 已经存在，无需重复导入。"
            else
                certutil -d sql:${certDBPath} -A -n "${certName}" -t "CT,C,c" -i ${certFile}
                isOK $? "导入证书文件${certFileName}作为证书${certName} "
            fi
        done
    done
    for certDB in $(find /home/${USERNAME} -name "cert8.db"); do
        certDBPath=$(dirname ${certDB})
        userPath=${certDBPath#/home/}
        username=${userPath%%/*}
        echo "为用户 ${username} 注册PKCS#11模块和导入证书链到${certDBPath}下的cert8.db中。"
        echo -n "    "
        mod_info=`modutil -dbdir ${certDBPath} -list|grep ${P11_MODULE_NAME}`
        if [ -n "$mod_info" ]; then
            echo "已经注册PKCS#11模块 ${P11_MODULE_NAME}，无需重复注册。" 
        else
            modutil -dbdir ${certDBPath} -add ${P11_MODULE_NAME} -libfile ${PKCS11_LIB} -force
            isOK $? "    注册PKCS#11模块 ${P11_MODULE_NAME} "
        fi
        for certFile in $(find ${CERT_PATH} -maxdepth 1 -name "*.crt"); do
            certFileName=${certFile##*/}
            certName=${certFileName%%.crt}
            certName=`echo $certName | sed "s/_/ /g"`
            echo -n "    "
            cert_info=`certutil -d ${certDBPath} -L|grep "${certName}"`
            if [ -n "$cert_info" ]; then
                echo "证书${certName} 已经存在，无需重复导入。"
            else
                certutil -d ${certDBPath} -A -n "${certName}" -t "CT,C,c" -i ${certFile}
                isOK $? "导入证书文件${certFileName}作为证书${certName} "
            fi
        done
    done
fi
echo "注册PKCS#11模块和导入证书链结束！"
