#!/bin/sh

# 定义变量
P11_MODULE_NAME="mTokenGM3000"
INSTALL_PATH="/opt/apps/com.longser.gm3000user/files"
CERT_LIST="CFCA_ACS_CA.crt CFCA_ACS_OCA31.crt mToken_Plugin_CA.crt"
USERNAME=$(whoami)

isOK ()
{
    [ $1 -eq 0 ] && echo "$2[\033[32m成功\033[0m]" || echo "$2[\033[31m失败\033[0m]"
}

# 删除pkcs11模块注册和证书链
echo "开始删除PKCS#11模块和证书链..."
if [ "$( which certutil )" = "" ];then
    echo "系统未安装 libnss3-tools 工具，无法自动删除PKCS#11模块和证书链。"
    echo "请手动将浏览器中PKCS#11模块和证书链删除。"
else
    for certDB in $(find /home/${USERNAME} -name "cert9.db"); do
        certDBPath=$(dirname ${certDB})
        userPath=${certDBPath#/home/}
        username=${userPath%%/*}
        echo "为用户 ${username} 删除${certDBPath}下cert9.db中的PKCS#11模块和证书链。"
        echo -n "    "
        mod_info=`modutil -dbdir sql:${certDBPath} -list|grep ${P11_MODULE_NAME}`
        if [ -n "$mod_info" ]; then
            modutil -dbdir sql:${certDBPath} -delete ${P11_MODULE_NAME} -force
            isOK $? "    删除PKCS#11模块 ${P11_MODULE_NAME} "
        else
            echo "未找到PKCS#11模块 ${P11_MODULE_NAME}。"
        fi
        for certFile in ${CERT_LIST}; do
            certName=${certFile%%.crt}
            certName=`echo $certName | sed "s/_/ /g"`
            echo -n "    "
            cert_info=`certutil -d sql:${certDBPath} -L|grep "${certName}"`
            if [ -n "$cert_info" ]; then
                certutil -d sql:${certDBPath} -D -n "${certName}"
                isOK $? "删除证书${certName} "
            else
                echo "未找到证书${certName}。"
            fi
        done
    done
    for certDB in $(find /home/${USERNAME} -name "cert8.db"); do
        certDBPath=$(dirname ${certDB})
        userPath=${certDBPath#/home/}
        username=${userPath%%/*}
        echo "为用户 ${username} 删除${certDBPath}下cert8.db中的PKCS#11模块和证书链。"
        echo -n "    "
        mod_info=`modutil -dbdir ${certDBPath} -list|grep ${P11_MODULE_NAME}`
        if [ -n "$mod_info" ]; then
            modutil -dbdir ${certDBPath} -delete ${P11_MODULE_NAME} -force
            isOK $? "    删除PKCS#11模块 ${P11_MODULE_NAME} "
        else
            echo "未找到PKCS#11模块 ${P11_MODULE_NAME}。"
        fi   
        for certFile in ${CERT_LIST}; do
            certName=${certFile%%.crt}
            certName=`echo $certName | sed "s/_/ /g"`
            echo -n "    "
            cert_info=`certutil -d ${certDBPath} -L|grep "${certName}"`
            if [ -n "$cert_info" ]; then
                certutil -d ${certDBPath} -D -n "${certName}"
                isOK $? "删除证书${certName} "
            else
                echo "未找到证书${certName}。"
            fi
        done

    done
fi
echo "删除PKCS#11模块和证书链结束。"
